Sorted = {}

local locales = {
    [1] = "enUS",
    [2] = "enGB",
    [3] = "frFR",
    [4] = "deDE",
    [5] = "itIT",
    [6] = "koKR",
    [7] = "zhCN",
    [8] = "zhTW",
    [9] = "ruRU",
    [10] = "esES",
    [11] = "esMX",
    [12] = "ptBR",
}
local localizations = {}
for _, locale in pairs(locales) do
    localizations[locale] = {}
end

local function ParseTSV()
-- Tab Separated Values spreadsheet imported directly from https://docs.google.com/spreadsheets/d/17eIDO0UU86-DUYjvu_ZyJ_9b8kMA9kTbAMDiQ0elXQA/edit?usp=sharing
local tsv = 
[[TITLE	Sorted.	Sorted.	Sorted.	Sorted.	Sorted.	Sorted.	Sorted.	Sorted.	Sorted.	Sorted.	Sorted.	Sorted.
CATEGORY_WEAPONS	Weapons	Weapons	Armes	Waffen	Armi	무기	武器	武器	Оружие	Armas	Armas	Armas
CATEGORY_ARMOR	Armor	Armour	Armure	Rüstung	Armature	방어구	护甲	護甲	Доспехи	Armadura	Armadura	Armadura
CATEGORY_ACCESSORIES	Accessories	Accessories	Accessoires	Accessoires	Accessori	장비	配件	配件	Аксессуары	Accesorios	Accesorios	Acessórios
CATEGORY_CONTAINERS	Containers	Containers	Conteneurs	Behälter	Borse	가방류	容器	容器	Сумки	Recipientes	Contenedores	Recipientes
CATEGORY_GEMS	Gems	Gems	Gemmes	Edelsteine	Gemme	보석	宝石	寶石	Камни	Gemas	Gemas	Gemas
CATEGORY_ITEM_ENHANCEMENTS	Item Enhancements	Item Enhancements	Améliorations d’objet	Gegenstandsverbesserungen	Potenziamenti oggetto	아이템 강화	物品附魔	物品附魔	Улучшения предметов	Mejoras de objetos	Mejoras de objetos	Aperfeiçoamentos de Itens
CATEGORY_CONSUMABLES	Consumables	Consumables	Consommables	Verbrauchbare Gegenstände	Consumabili	소비용품	消耗品	消耗品	Расход. предметы	Consumibles	Consumibles	Consumíveis
CATEGORY_GLYPHS	Glyphs	Glyphs	Glyphes	Glyphen	Glifi	문양	雕文	雕紋	Символы	Glifos	Glifos	Glifos
CATEGORY_TRADE_GOODS	Trade Goods	Trade Goods	Fournitures d’artisanat	Handwerkswaren	Beni commerciali	직업용품	杂货	商品	Хозяйственные товары	Objetos comerciales	Objetos comerciables	Mercadorias
CATEGORY_RECIPES	Recipes	Recipes	Recettes	Rezepte	Ricette	제조법	配方	配方	Рецепты	Recetas	Recetas	Receitas
CATEGORY_BATTLE_PETS	Battle Pets	Battle Pets	Mascottes de combat	Kampfhaustiere	Mascotte da combattimento	전투 애완동물	战斗宠物	戰寵	Боевые питомцы	Mascotas de duelo	Mascotas de duelo	Mascotes de Batalha
CATEGORY_QUEST_ITEMS	Quest Items	Quest Items	Objets de quête	Questgegenstände	Oggetti di missione	퀘스트 아이템	任务物品	任務物品	Предметы	Objetos de misión	Objetos con misión	Itens de missão
CATEGORY_MISCELLANEOUS	Miscellaneous	Miscellaneous	Divers	Verschiedenes	Varie	기타	杂项	雜項	Разное	Miscelánea	Miscelánea	Diversos
ITEM_UNKNOWN_KEYSTONE	Mythic Keystone	Mythic Keystone				신화 쐐기돌		傳奇鑰石				
ITEM_MYTHIC_KEYSTONE	Keystone: %s	Keystone: %s				쐐기돌: %s		鑰石：%s				
ITEM_PET_CAGED	Pet Cage: %s	Pet Cage: %s				애완동물 우리: %s		寵物籠：%s				
COLUMN_FAVORITES	Favorites	Favourites				즐겨찾기		最愛				
COLUMN_QUANTITY	Quantity	Quantity				수량		數量				
COLUMN_ICON	Icon	Icon										
COLUMN_NAME	Name	Name				이름		名稱				
COLUMN_NAME_SHORT	Name	Name				이름		名稱				
COLUMN_RARITY_SHORT	Rarity	Rarity				희박		稀有度				
COLUMN_REQUIRED_LEVEL	Required Level	Required Level				최소 요구 레벨		需求等級				
COLUMN_REQUIRED_LEVEL_SHORT	Req	Req				최소렙		需求				
COLUMN_ITEM_LEVEL	Item Level	Item Level				아이템 레벨		物品等級				
COLUMN_ITEM_LEVEL_SHORT	Lvl	Lvl				템렙		等級				
COLUMN_TIME_ADDED	Time Added	Time Added										
COLUMN_TIME_ADDED_SHORT	Age	Age										
COLUMN_TYPE	Type	Type				종류		類型				
COLUMN_TYPE_SHORT	Type	Type				종류		類型				
COLUMN_BINDING	Binding	Binding				귀속		綁定類型				
COLUMN_BINDING_SHORT	Bind	Bind				귀속		綁定				
COLUMN_EXPANSION	Expansion	Expansion				확장팩		資料片				
COLUMN_EXPANSION_SHORT	Expac	Expac				확팩		資料片				
COLUMN_SELL_PRICE	Sell Price	Sell Price				판매 가격		售出價格				
COLUMN_SELL_PRICE_SHORT	Value	Value				값		售價				
TAB_BANK	Bank	Bank				은행		銀行				
TAB_REAGENTS	Reagents	Reagents				재료 은행		材料銀行				
BUTTON_SELL_GRAYS	Sell Grays	Sell Greys										
BUTTON_DEPOSIT_REAGENTS	Deposit Reagents	Deposit Reagents				모든 재료 보관		存入材料				
BUTTON_BUY_REAGENTS	Purchase	Purchase				구입		購買				
WARNING_BUY_REAGENTS	This tab gives you additional storage for raw profession materials.\nDo you wish to purchase this tab?	This tab gives you additional storage for raw profession materials.\nDo you wish to purchase this tab?				이 보관함에는 직업용품을 추가로 보관할 수 있습니다.\n이 보관함을 구입하시겠습니까?		此標籤為您提供了額外的存儲專業原料的空間。\n您想要購買此標籤頁嗎？				
WARNING_NO_ITEMS_FOUND	No items found	No items found				아이템을 찾을 수 없음		沒找到物品				
WARNING_BANK_NOT_CACHED	Visit a banker once on %s\n to see their bank contents here	Visit a banker once on %s\n to see their bank contents here				은행원에게 한 번 방문하여\n이곳에서 %s의 은행 확인		訪問銀行行員一次在 %s\n來查閱他們的銀行物品				
WARNING_REAGENTS_NOT_CACHED	Visit a banker once on %s\n to see the contents of their reagent bank here	Visit a banker once on %s\n to see the contents of their reagent bank here				은행원에게 한 번 방문하여\n이곳에서 %s의 재료 은행 확인		訪問銀行行員一次在 %s\n來查閱他們的材料銀行物品				
WARNING_REAGENTS_NOT_PURCHASED	Visit a banker on %s\n to purchase their reagent bank	Visit a banker on %s\n to purchase their reagent bank				은행원에게 방문하여\n%s의 재료 은행 구입		訪問銀行行員在 %s\n來購買他們的材料銀行				
DROPDOWN_MENU_EQUIPMENT_SET	Equipment Sets	Equipment Sets				장비 세트		套裝設定				
DROPDOWN_MENU_EQUIPMENT_SET_NONE	No Equipment Set	No Equipment Set										
DROPDOWN_MENU_CLEAR	Clear	Clear				초기화		清除				
FILTER_TYPE	Type	Type				종류		類型				
FILTER_EQUIP_LOCATION	Equip Location	Equip Location				착용 부위		裝備位置				
FILTER_SUBTYPE	Subtype	Subtype				소분류		子類別				
FILTER_STATS	Stats	Stats				능력치		屬性				
FILTER_QUALITY	Quality	Quality				품질		品質				
FILTER_TIME_ADDED	Time Added	Time Added				획득 시간		加入時間				
FILTER_BINDING	Binding	Binding				귀속		綁定				
FILTER_EXPANSION	Expansion	Expansion				확장팩		資料片				
FILTER_LEVEL	Level	Level				레벨		等級				
FILTER_MARKER_ICON	Marker Icon	Marker Icon				징표		標記圖示				
FILTER_NAME_SEARCH	Name Search	Name Search				이름 검색		名稱搜尋				
FILTER_SPECIFIC_ITEMS	Specific Items	Specific Items				특정 아이템		特定物品				
SUBFILTER_TYPE_ARMOR	Armor	Armour				방어구		護甲				
SUBFILTER_TYPE_BATTLE_PET	Battle Pet	Battle Pet				전투 애완동물		戰寵				
SUBFILTER_TYPE_CONSUMABLE	Consumable	Consumable				소모성		消耗品				
SUBFILTER_TYPE_CONTAINER	Container	Container				가방		容器				
SUBFILTER_TYPE_GEM	Gem	Gem				보석		寶石				
SUBFILTER_TYPE_GLYPH	Glyph	Glyph				문양		雕紋				
SUBFILTER_TYPE_ITEM_ENHANCEMENT	Item Enhancement	Item Enhancement				아이템 강화		物品附魔				
SUBFILTER_TYPE_KEY	Key	Key				열쇠		鑰匙				
SUBFILTER_TYPE_MISCELLANEOUS	Miscellaneous	Miscellaneous				기타		雜項				
SUBFILTER_TYPE_REAGENT	Reagent	Reagent				재료		試劑				
SUBFILTER_TYPE_RECIPE	Recipe	Recipe				습득서		配方				
SUBFILTER_TYPE_PROJECTILE	Projectile	Projectile				발사체		發射物				
SUBFILTER_TYPE_QUEST	Quest	Quest				퀘스트		任務				
SUBFILTER_TYPE_QUIVER	Quiver	Quiver				화살통		箭袋				
SUBFILTER_TYPE_TRADE_GOODS	Trade Good	Trade Good				직업용품		商品				
SUBFILTER_TYPE_WEAPON	Weapon	Weapon				무기		武器				
SUBFILTER_EQUIP_LOCATION_HEAD	Head	Head				머리		頭部				
SUBFILTER_EQUIP_LOCATION_NECK	Neck	Neck				목		頸部				
SUBFILTER_EQUIP_LOCATION_SHOULDER	Shoulder	Shoulder				어깨		肩部				
SUBFILTER_EQUIP_LOCATION_BACK	Back	Back				등		背部				
SUBFILTER_EQUIP_LOCATION_CHEST	Chest	Chest				가슴		胸部				
SUBFILTER_EQUIP_LOCATION_SHIRT	Shirt	Shirt				속옷		襯衣				
SUBFILTER_EQUIP_LOCATION_TABARD	Tabard	Tabard				겉옷		外袍				
SUBFILTER_EQUIP_LOCATION_WRIST	Wrist	Wrist				손목		手腕				
SUBFILTER_EQUIP_LOCATION_HANDS	Hands	Hands				손		手				
SUBFILTER_EQUIP_LOCATION_WAIST	Waist	Waist				허리		腰部				
SUBFILTER_EQUIP_LOCATION_LEGS	Legs	Legs				다리		腿部				
SUBFILTER_EQUIP_LOCATION_FEET	Feet	Feet				발		腳				
SUBFILTER_EQUIP_LOCATION_FINGER	Finger	Finger				손가락		手指				
SUBFILTER_EQUIP_LOCATION_TRINKET	Trinket	Trinket				장신구		飾品				
SUBFILTER_EQUIP_LOCATION_OFF_HAND	Off-Hand	Off-Hand				보조장비		副手				
SUBFILTER_EQUIP_LOCATION_RELIC	Relic	Relic				유물		聖物				
SUBFILTER_EQUIP_LOCATION_ONE_HAND	One-Handed	One-Handed				한손		單手				
SUBFILTER_EQUIP_LOCATION_TWO_HAND	Two-Handed	Two-Handed				양손		雙手				
SUBFILTER_EQUIP_LOCATION_RANGED	Ranged	Ranged				원거리		遠程				
SUBFILTER_SUBTYPE_ARMOR_PLATE	Plate	Plate				판금		鎧甲				
SUBFILTER_SUBTYPE_ARMOR_MAIL	Mail	Mail				사슬		鎖甲				
SUBFILTER_SUBTYPE_ARMOR_LEATHER	Leather	Leather				가죽		皮甲				
SUBFILTER_SUBTYPE_ARMOR_CLOTH	Cloth	Cloth				천		布甲				
SUBFILTER_SUBTYPE_ARMOR_COSMETIC	Cosmetic	Cosmetic				장식		造型				
SUBFILTER_SUBTYPE_ARMOR_GENERIC	Generic	Generic				포괄적		一般				
SUBFILTER_SUBTYPE_ARMOR_SHIELDS	Shields	Shields				방패		盾牌				
SUBFILTER_SUBTYPE_ARMOR_LIBRAMS	Librams	Librams				고서		聖契				
SUBFILTER_SUBTYPE_ARMOR_IDOLS	Idols	Idols				우상		雕像				
SUBFILTER_SUBTYPE_ARMOR_TOTEMS	Totems	Totems				토템		圖騰				
SUBFILTER_SUBTYPE_ARMOR_SIGILS	Sigils	Sigils				인장		符印				
SUBFILTER_SUBTYPE_BATTLE_PET_HUMANOID	Humanoid	Humanoid				인간형		人形生物				
SUBFILTER_SUBTYPE_BATTLE_PET_DRAGON	Dragon	Dragon				용족		龍類				
SUBFILTER_SUBTYPE_BATTLE_PET_FLYING	Flying	Flying				비행		飛行				
SUBFILTER_SUBTYPE_BATTLE_PET_UNDEAD	Undead	Undead				언데드		不死				
SUBFILTER_SUBTYPE_BATTLE_PET_CRITTER	Critter	Critter				동물		小動物				
SUBFILTER_SUBTYPE_BATTLE_PET_MAGICAL	Magical	Magical				마법		魔法				
SUBFILTER_SUBTYPE_BATTLE_PET_ELEMENTAL	Elemental	Elemental				정령		元素				
SUBFILTER_SUBTYPE_BATTLE_PET_BEAST	Beast	Beast				야수		野獸				
SUBFILTER_SUBTYPE_BATTLE_PET_WATER	Water	Water				물		水棲				
SUBFILTER_SUBTYPE_BATTLE_PET_MECHANICAL	Mechanical	Mechanical				기계		機械				
SUBFILTER_SUBTYPE_CONSUMABLE_BOMBS_AND_DEVICES	Bombs and Devices	Bombs and Devices				폭탄과 장치		爆裂物與裝置				
SUBFILTER_SUBTYPE_CONSUMABLE_POTIONS	Potions	Potions				물약		藥水				
SUBFILTER_SUBTYPE_CONSUMABLE_ELIXIRS	Elixirs	Elixirs				비약		藥劑				
SUBFILTER_SUBTYPE_CONSUMABLE_FLASKS	Flasks	Flasks				영약		精煉藥劑				
SUBFILTER_SUBTYPE_CONSUMABLE_FOOD_AND_DRINK	Food & Drink	Food & Drink				음식과 음료		食物和飲料				
SUBFILTER_SUBTYPE_CONSUMABLE_BANDAGES	Bandages	Bandages				붕대		繃帶				
SUBFILTER_SUBTYPE_CONSUMABLE_VANTUS_RUNES	Vantus Runes	Vantus Runes				반투스 룬		梵陀符文				
SUBFILTER_SUBTYPE_CONSUMABLE_OTHER	Other	Other				그 외		其他				
SUBFILTER_SUBTYPE_CONTAINER_BAG	Bag	Bag				가방		背包				
SUBFILTER_SUBTYPE_CONTAINER_SOUL	Soul Bag	Soul Bag				영혼석 가방		靈魂袋				
SUBFILTER_SUBTYPE_CONTAINER_HERB	Herb Bag	Herb Bag				약초 가방		草藥包				
SUBFILTER_SUBTYPE_CONTAINER_ENCHANTING	Enchanting Bag	Enchanting Bag				마법부여 가방		附魔包				
SUBFILTER_SUBTYPE_CONTAINER_ENGINEERING	Engineering Bag	Engineering Bag				기계공학 가방		工程包				
SUBFILTER_SUBTYPE_CONTAINER_GEM	Gem Bag	Gem Bag				보석 가방		寶石包				
SUBFILTER_SUBTYPE_CONTAINER_MINING	Mining Bag	Mining Bag				채광 가방		礦石包				
SUBFILTER_SUBTYPE_CONTAINER_LEATHERWORKING	Leatherworking Bag	Leatherworking Bag				가죽세공 가방		製皮包				
SUBFILTER_SUBTYPE_CONTAINER_INSCRIPTION	Inscription Bag	Inscription Bag				주문각인 가방		銘文包				
SUBFILTER_SUBTYPE_CONTAINER_TACKLE	Tackle Box	Tackle Box				낚시 가방		釣餌箱				
SUBFILTER_SUBTYPE_CONTAINER_COOKING	Cooking Bag	Cooking Bag				요리 가방		烹飪包				
SUBFILTER_SUBTYPE_GEM_INTELLECT	Intellect	Intellect				지능		智力				
SUBFILTER_SUBTYPE_GEM_AGILITY	Agility	Agility				민첩		敏捷				
SUBFILTER_SUBTYPE_GEM_STRENGTH	Strength	Strength				힘		力量				
SUBFILTER_SUBTYPE_GEM_STAMINA	Stamina	Stamina				체력		耐力				
SUBFILTER_SUBTYPE_GEM_SPIRIT	Spirit	Spirit				영혼		精神				
SUBFILTER_SUBTYPE_GEM_CRITICAL_STRIKE	Critical Strike	Critical Strike				치명타		致命一擊				
SUBFILTER_SUBTYPE_GEM_MASTERY	Mastery	Mastery				특화		精通				
SUBFILTER_SUBTYPE_GEM_HASTE	Haste	Haste				가속		加速				
SUBFILTER_SUBTYPE_GEM_VERSATILITY	Versatility	Versatility				유연성		臨機應變				
SUBFILTER_SUBTYPE_GEM_OTHER	Other	Other				그 외		其他				
SUBFILTER_SUBTYPE_GEM_MULTIPLE_STATS	Multiple Stats	Multiple Stats				다중 능력치		多項屬性				
SUBFILTER_SUBTYPE_GEM_ARTIFACT_RELIC	Artifact Relic	Artefact Relic				유물 보석		神兵聖物				
SUBFILTER_SUBTYPE_GLYPH_WARRIOR	Warrior	Warrior				전사		戰士				
SUBFILTER_SUBTYPE_GLYPH_PALADIN	Paladin	Paladin				성기사		聖騎士				
SUBFILTER_SUBTYPE_GLYPH_HUNTER	Hunter	Hunter				사냥꾼		獵人				
SUBFILTER_SUBTYPE_GLYPH_ROGUE	Rogue	Rogue				도적		盜賊				
SUBFILTER_SUBTYPE_GLYPH_PRIEST	Priest	Priest				사제		牧師				
SUBFILTER_SUBTYPE_GLYPH_DEATH_KNIGHT	Death Knight	Death Knight				죽음의 기사		死亡騎士				
SUBFILTER_SUBTYPE_GLYPH_SHAMAN	Shaman	Shaman				주술사		薩滿				
SUBFILTER_SUBTYPE_GLYPH_MAGE	Mage	Mage				마법사		法師				
SUBFILTER_SUBTYPE_GLYPH_WARLOCK	Warlock	Warlock				흑마법사		術士				
SUBFILTER_SUBTYPE_GLYPH_MONK	Monk	Monk				수도사		武僧				
SUBFILTER_SUBTYPE_GLYPH_DRUID	Druid	Druid				드루이드		德魯伊				
SUBFILTER_SUBTYPE_GLYPH_DEMON_HUNTER	Demon Hunter	Demon Hunter				악마 사냥꾼		惡魔獵人				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_HEAD	Head	Head				머리		頭部				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_NECK	Neck	Neck				목		頸部				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_SHOULDER	Shoulder	Shoulder				어깨		肩部				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_CLOAK	Cloak	Cloak				등		背部				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_CHEST	Chest	Chest				가슴		胸部				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_WRIST	Wrist	Wrist				손목		手腕				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_HANDS	Hands	Hands				손		手				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_WAIST	Waist	Waist				허리		腰部				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_LEGS	Legs	Legs				다리		腿部				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_FEET	Feet	Feet				발		腳				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_FINGER	Finger	Finger				손가락		手指				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_ONE_HAND	One-Handed Weapons	One-Handed Weapons				한손 무기		單手武器				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_TWO_HAND	Two-Handed Weapons	Two-Handed Weapons				양손 무기		雙手武器				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_SHIELD_OFF_HAND	Shield/Offhand	Shield/Offhand				방패/보조무기		盾牌/副手				
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_MISCELLANEOUS	Misc	Misc				기타		雜項				
SUBFILTER_SUBTYPE_KEY_KEY	Key	Key				열쇠		鑰匙				
SUBFILTER_SUBTYPE_KEY_LOCKPICK	Lockpick	Lockpick				자물쇠		開鎖器				
SUBFILTER_SUBTYPE_MISCELLANEOUS_JUNK	Junk	Junk				하급		垃圾				
SUBFILTER_SUBTYPE_MISCELLANEOUS_REAGENTS	Spell Reagents	Spell Reagents				주문 재료		施法材料				
SUBFILTER_SUBTYPE_MISCELLANEOUS_COMPANION_PETS	Companion Pets	Companion Pets				전투 애완동물		寵物夥伴				
SUBFILTER_SUBTYPE_MISCELLANEOUS_HOLIDAY	Holiday	Holiday				이벤트		節慶用品				
SUBFILTER_SUBTYPE_MISCELLANEOUS_OTHER	Other	Other				그 외		其他				
SUBFILTER_SUBTYPE_MISCELLANEOUS_MOUNT	Mount	Mount				탈것		坐騎				
SUBFILTER_SUBTYPE_MISCELLANEOUS_MOUNT_EQUIPMENT	Mount Equipment	Mount Equipment				탈것 장비		坐騎裝備				
SUBFILTER_SUBTYPE_RECIPE_BOOK	Book	Book				책		書籍				
SUBFILTER_SUBTYPE_RECIPE_LEATHERWORKING	Leatherworking	Leatherworking				가죽세공		製皮				
SUBFILTER_SUBTYPE_RECIPE_TAILORING	Tailoring	Tailoring				주문각인		裁縫				
SUBFILTER_SUBTYPE_RECIPE_ENGINEERING	Engineering	Engineering				기계공학		工程學				
SUBFILTER_SUBTYPE_RECIPE_BLACKSMITHING	Blacksmithing	Blacksmithing				대장기술		鍛造				
SUBFILTER_SUBTYPE_RECIPE_COOKING	Cooking	Cooking				요리		烹飪				
SUBFILTER_SUBTYPE_RECIPE_ALCHEMY	Alchemy	Alchemy				연금술		煉金術				
SUBFILTER_SUBTYPE_RECIPE_FIRST_AID	First Aid	First Aid				응급치료		急救				
SUBFILTER_SUBTYPE_RECIPE_ENCHANTING	Enchanting	Enchanting				마법부여		附魔				
SUBFILTER_SUBTYPE_RECIPE_FISHING	Fishing	Fishing				낚시		釣魚				
SUBFILTER_SUBTYPE_RECIPE_JEWELCRAFTING	Jewelcrafting	Jewelcrafting				보석세공		珠寶設計				
SUBFILTER_SUBTYPE_RECIPE_INSCRIPTION	Inscription	Inscription				주문각인		銘文				
SUBFILTER_SUBTYPE_PROJECTILE_ARROW	Arrow	Arrow				화살		箭				
SUBFILTER_SUBTYPE_PROJECTILE_BULLET	Bullet	Bullet				탄약		子彈				
SUBFILTER_SUBTYPE_QUIVER_QUIVER	Quiver	Quiver				화살통		箭袋				
SUBFILTER_SUBTYPE_QUIVER_AMMO_POUCH	Ammo Pouch	Ammo Pouch				탄약 주머니		彈藥袋				
SUBFILTER_SUBTYPE_TRADE_GOODS_PARTS	Parts	Parts				부품		零件				
SUBFILTER_SUBTYPE_TRADE_GOODS_JEWELCRAFTING	Jewelcrafting	Jewelcrafting				보석세공		珠寶設計				
SUBFILTER_SUBTYPE_TRADE_GOODS_CLOTH	Cloth	Cloth				천		布料				
SUBFILTER_SUBTYPE_TRADE_GOODS_LEATHER	Leather	Leather				가죽		皮革				
SUBFILTER_SUBTYPE_TRADE_GOODS_METAL_AND_STONE	Metal & Stone	Metal & Stone				금속 & 돌		金屬與石頭				
SUBFILTER_SUBTYPE_TRADE_GOODS_COOKING	Cooking	Cooking				요리		烹飪				
SUBFILTER_SUBTYPE_TRADE_GOODS_HERB	Herb	Herb				약초		草藥				
SUBFILTER_SUBTYPE_TRADE_GOODS_ELEMENTAL	Elemental	Elemental				원소		元素材料				
SUBFILTER_SUBTYPE_TRADE_GOODS_ENCHANTING	Enchanting	Enchanting				마법부여		附魔				
SUBFILTER_SUBTYPE_TRADE_GOODS_INSCRIPTION	Inscription	Inscription				주문각인		銘文				
SUBFILTER_SUBTYPE_TRADE_GOODS_OTHER	Other	Other				그 외		其他				
SUBFILTER_SUBTYPE_WEAPON_AXES	Axes	Axes				도끼		斧				
SUBFILTER_SUBTYPE_WEAPON_MACES	Maces	Maces				둔기		錘				
SUBFILTER_SUBTYPE_WEAPON_SWORDS	Swords	Swords				도검		劍				
SUBFILTER_SUBTYPE_WEAPON_DAGGERS	Daggers	Daggers				단검		匕首				
SUBFILTER_SUBTYPE_WEAPON_POLEARMS	Polearms	Polearms				장창		長柄				
SUBFILTER_SUBTYPE_WEAPON_FIST	Fist Weapons	Fist Weapons				장착무기		拳套				
SUBFILTER_SUBTYPE_WEAPON_GLAIVES	Warglaives	Warglaives				전투검		戰刃				
SUBFILTER_SUBTYPE_WEAPON_WANDS	Wands	Wands				마법봉		魔杖				
SUBFILTER_SUBTYPE_WEAPON_STAVES	Staves	Staves				지팡이		法杖				
SUBFILTER_SUBTYPE_WEAPON_BOWS	Bows	Bows				활		弓				
SUBFILTER_SUBTYPE_WEAPON_CROSSBOWS	Crossbows	Crossbows				석궁		弩				
SUBFILTER_SUBTYPE_WEAPON_GUNS	Guns	Guns				총		槍械				
SUBFILTER_SUBTYPE_WEAPON_THROWN	Thrown	Thrown				투척		投擲武器				
SUBFILTER_SUBTYPE_WEAPON_FISHING_POLES	Fishing Poles	Fishing Poles				낚싯대		魚竿				
SUBFILTER_SUBTYPE_WEAPON_MISCELLANEOUS	Miscellaneous	Miscellaneous				기타		雜項				
SUBFILTER_STATS_STAMINA	Stamina	Stamina				체력		耐力				
SUBFILTER_STATS_STRENGTH	Strength	Strength				힘		力量				
SUBFILTER_STATS_AGILITY	Agility	Agility				민첩		敏捷				
SUBFILTER_STATS_INTELLECT	Intellect	Intellect				지능		智力				
SUBFILTER_STATS_CRITICAL_STRIKE	Critical Strike	Critical Strike				치명타		致命一擊				
SUBFILTER_STATS_HASTE	Haste	Haste				가속		加速				
SUBFILTER_STATS_MASTERY	Mastery	Mastery				특화		精通				
SUBFILTER_STATS_VERSATILITY	Versatility	Versatility				유연성		臨機應變				
SUBFILTER_STATS_SPEED	Speed	Speed				이동속도		速度				
SUBFILTER_STATS_INDESTRUCTIBLE	Indestructible	Indestructible				파괴 불가		永不磨損				
SUBFILTER_STATS_LEECH	Leech	Leech				생기흡수		汲取				
SUBFILTER_STATS_AVOIDANCE	Avoidance	Avoidance				회피		迴避				
SUBFILTER_QUALITY_HEIRLOOM	Heirloom	Heirloom				계승		傳家寶				
SUBFILTER_QUALITY_ARTIFACT	Artifact	Artefact				유물		神器				
SUBFILTER_QUALITY_LEGENDARY	Legendary	Legendary				전설		傳奇				
SUBFILTER_QUALITY_EPIC	Epic	Epic				영웅		史詩				
SUBFILTER_QUALITY_RARE	Rare	Rare				희귀		精良				
SUBFILTER_QUALITY_UNCOMMON	Uncommon	Uncommon				고급		良好				
SUBFILTER_QUALITY_COMMON	Common	Common				일반		普通				
SUBFILTER_QUALITY_POOR	Poor	Poor				하급		粗劣				
SUBFILTER_TIME_SECOND_SHORT	Sec	Sec				초		秒				
SUBFILTER_TIME_SECONDS	Seconds	Seconds				초		秒				
SUBFILTER_TIME_SECONDS_SHORT	Secs	Secs				초		秒				
SUBFILTER_TIME_MINUTE_SHORT	Min	Min				분		分				
SUBFILTER_TIME_MINUTES	Minutes	Minutes				분		分鐘				
SUBFILTER_TIME_MINUTES_SHORT	Mins	Mins				분		分				
SUBFILTER_TIME_HOUR_SHORT	Hour	Hour				시		小時				
SUBFILTER_TIME_HOURS	Hours	Hours				시간		小時				
SUBFILTER_TIME_HOURS_SHORT	Hrs	Hrs				시		小時				
SUBFILTER_TIME_DAY_SHORT	Day	Day				일		天				
SUBFILTER_TIME_DAYS	Days	Days				일		天				
SUBFILTER_TIME_DAYS_SHORT	Days	Days				일		天				
SUBFILTER_TIME_WEEK_SHORT	Week	Week				주		週				
SUBFILTER_TIME_WEEKS	Weeks	Weeks				주		週				
SUBFILTER_TIME_WEEKS_SHORT	Wks	Wks				주		週				
SUBFILTER_TIME_MONTH_SHORT	Mnth	Mnth				월		月				
SUBFILTER_TIME_MONTHS	Months	Months				개월		月				
SUBFILTER_TIME_MONTHS_SHORT	Mths	Mths				월		月				
SUBFILTER_TIME_YEAR_SHORT	Year	Year										
SUBFILTER_TIME_YEARS	Years	Years										
SUBFILTER_TIME_YEARS_SHORT	Yrs	Yrs										
SUBFILTER_BINDING_NONE	None	None				없음		無				
SUBFILTER_BINDING_ON_EQUIP	Bind on Equip	Bind on Equip				착용 시 귀속		裝備後				
SUBFILTER_BINDING_ON_EQUIP_SHORT	Equip	Equip				착귀		裝綁				
SUBFILTER_BINDING_ON_PICKUP	Bind on Pickup	Bind on Pickup				획득 시 귀속		拾取後				
SUBFILTER_BINDING_ON_PICKUP_SHORT	Pickup	Pickup				획귀		拾綁				
SUBFILTER_BINDING_ON_USE	Bind on Use	Bind on Use				사용 시 귀속		使用後				
SUBFILTER_BINDING_ON_USE_SHORT	Use	Use				사용		用綁				
SUBFILTER_BINDING_SOULBOUND	Soulbound	Soulbound				계정 귀속		靈魂綁定				
SUBFILTER_BINDING_SOULBOUND_SHORT	Bound	Bound				계귀		綁定				
SUBFILTER_EXPANSION_TBC	The Burning Crusade	The Burning Crusade				불타는 성전		燃燒的遠征				
SUBFILTER_EXPANSION_TBC_SHORT	TBC	TBC				불성		遠征				
SUBFILTER_EXPANSION_WOTLK	Wrath of the Lich King	Wrath of the Lich King				리치왕의 분노		巫妖王之怒				
SUBFILTER_EXPANSION_WOTLK_SHORT	Wrath	Wrath				리분		巫妖王				
SUBFILTER_EXPANSION_CATA	Cataclysm	Cataclysm				대격변		浩劫與重生				
SUBFILTER_EXPANSION_CATA_SHORT	Cata	Cata				격변		浩劫				
SUBFILTER_EXPANSION_MOP	Mists of Pandaria	Mists of Pandaria				판다리아의 안개		潘達利亞迷霧				
SUBFILTER_EXPANSION_MOP_SHORT	MoP	MoP				판다		潘達				
SUBFILTER_EXPANSION_WOD	Warlords of Draenor	Warlords of Draenor				드레노어의 전쟁군주		德拉諾之霸				
SUBFILTER_EXPANSION_WOD_SHORT	WoD	WoD				드군		德拉諾				
SUBFILTER_EXPANSION_LEGION	Legion	Legion				군단		軍臨天下				
SUBFILTER_EXPANSION_LEGION_SHORT	Legion	Legion				군단		軍臨				
SUBFILTER_EXPANSION_BFA	Battle for Azeroth	Battle for Azeroth				격전의 아제로스		決戰艾澤拉斯				
SUBFILTER_EXPANSION_BFA_SHORT	BfA	BfA				격아		決戰				
SUBFILTER_EXPANSION_SHADOW	Shadowlands	Shadowlands				어둠땅		暗影之境				
SUBFILTER_EXPANSION_SHADOW_SHORT	Shadow	Shadow				둠땅		暗影				
SUBFILTER_LEVEL_ITEM_LEVEL	Item Level	Item Level				아이템 레벨		物品等級				
SUBFILTER_LEVEL_REQUIRED_LEVEL	Required Level	Required Level				착용 레벨		需求等級				
SUBFILTER_MARKER_ICON_NONE	None	None				없음		無				
SUBFILTER_SPECIFIC_ITEMS_ID	ID	ID				ID		ID				
SUBFILTER_SPECIFIC_ITEMS_NAME	Name	Name				이름		名稱				
CONFIG_APPEARANCE	Appearance	Appearance				외형		外觀				
CONFIG_BEHAVIOR	Behavior	Behavior				동작		動作				
CONFIG_CATEGORIES	Categories	Categories				분류		類別				
CONFIG_COLUMNS	Columns	Columns				열		欄目				
CONFIG_PROFILES	Profiles	Profiles				프로필		設定檔				
CONFIG_APPEARANCE_SCALE	Scale	Scale				크기 비율		縮放				
CONFIG_APPEARANCE_ICON_SIZE	Icon Size	Icon Size				아이콘 크기		圖示尺寸				
CONFIG_APPEARANCE_ICON_BORDERS	Icon Borders	Icon Borders				아이콘 테두리		圖示外框				
CONFIG_APPEARANCE_SPACING	Spacing	Spacing				간격		間距				
CONFIG_APPEARANCE_BACKDROP_OPACITY	Backdrop Opacity	Backdrop Opacity				배경 투명도		背景透明度				
CONFIG_APPEARANCE_FONT	Font	Font				폰트		字體				
CONFIG_APPEARANCE_FONT_SIZE	Size	Size				크기		尺寸				
CONFIG_APPEARANCE_FONT_SIZE_1	Tiny	Tiny	1	1	1	매우 작음	1	1	1	1	1	1
CONFIG_APPEARANCE_FONT_SIZE_2	Small	Small	2	2	2	작음	2	2	2	2	2	2
CONFIG_APPEARANCE_FONT_SIZE_3	Normal	Normal	3	3	3	중간	3	3	3	3	3	3
CONFIG_APPEARANCE_FONT_SIZE_4	Large	Large	4	4	4	큼	4	4	4	4	4	4
CONFIG_APPEARANCE_FONT_SIZE_5	Huge	Huge	5	5	5	매우 큼	5	5	5	5	5	5
CONFIG_APPEARANCE_FONT_OUTLINE	Outline	Outline				외곽선		描邊				
CONFIG_APPEARANCE_FONT_OUTLINE_1	None	None	1	1	1	없음	1	1	1	1	1	1
CONFIG_APPEARANCE_FONT_OUTLINE_2	Thin	Thin	2	2	2	얇은	2	2	2	2	2	2
CONFIG_APPEARANCE_FONT_OUTLINE_3	Thick	Thick	3	3	3	굵은	3	3	3	3	3	3
CONFIG_APPEARANCE_SIDE_PANE_WIDTH	Side Pane Width	Side Pane Width				측면 칸 넓이		側窗格寬度				
CONFIG_APPEARANCE_ALWAYS_USE_ICONS	Always Use Icons	Always Use Icons				항상 아이콘 사용		永遠使用圖示				
CONFIG_BEHAVIOR_SCROLL_WHEEL_SPEED	Wheel Scroll Speed	Wheel Scroll Speed				스크롤 속도		滾輪捲動速度				
CONFIG_BEHAVIOR_SMOOTH_SCROLLING	Smooth Scrolling	Smooth Scrolling				부드러운 스크롤		平滑捲動				
CONFIG_BEHAVIOR_SMOOTH_SCROLLING_POWER	Smoothing Strength	Smoothing Strength				부드러움 강도						
CONFIG_BEHAVIOR_ANIMATIONS	Animations	Animations				애니메이션		動畫效果				
CONFIG_BEHAVIOR_RESET_WINDOW	Reset Window on Close	Reset Window on Close				닫으면 창 초기화		關閉後重設視窗				
CONFIG_BEHAVIOR_COMBINE_STACKS	Combine Stacks	Combine Stacks				갯수 합치기		合併堆疊				
CONFIG_BEHAVIOR_TOOLTIP_DELAY	Tooltip Delay	Tooltip Delay				툴팁 등장 속도		工具提示延遲				
CONFIG_BEHAVIOR_TOOLTIP_DELAY_SECOND	Second	Second				초		秒				
CONFIG_BEHAVIOR_TOOLTIP_DELAY_SECONDS	Seconds	Seconds				초		秒				
CONFIG_CATEGORIES_NAME	Name	Name				이름		名稱				
CONFIG_CATEGORIES_ICON	Icon	Icon				아이콘		圖示				
CONFIG_CATEGORIES_FILTERS	Filters	Filters				필터		類別篩選				
CONFIG_CATEGORIES_ADD	Add Category	Add Category				분류 추가		新增類別				
CONFIG_CATEGORIES_DEFAULT_NAME	New Category	New Category				새 카테고리		新類別				
CONFIG_COLUMNS_COLUMN	Column	Column				열		欄目				
CONFIG_COLUMNS_WIDTH	Width	Width				넓이		寬度				
CONFIG_COLUMNS_ENABLED	Enabled	Enabled				활성화		啟用				
CONFIG_PROFILES_PROFILE	Settings Profile	Settings Profile				사용중인 프로필		配置設定檔				
CONFIG_PROFILES_NAME	Name	Name				이름		名稱				
CONFIG_PROFILES_NEW	New	New				생성		新				
CONFIG_PROFILES_COPY	Copy	Copy				복사		複製				
CONFIG_PROFILES_DELETE	Delete	Delete				삭제		刪除				
CONFIG_PROFILES_DEFAULT_NAME	New Profile	New Profile				새 프로필		新設定檔				
TOOLTIP_TITLE_ACCOUNT_GOLD	Account Gold	Account Gold				계정 골드		帳號金錢				
TOOLTIP_TITLE_BAGS	Bags	Bags				가방		背包				
TOOLTIP_TITLE_BANK	Bank Bags	Bank Bags				은행 가방		銀行容器				
TOOLTIP_TITLE_REAGENTS	Reagent Bank	Reagent Bank				재료 가방		材料銀行				
TOOLTIP_CONFIG	Configure Sorted.	Configure Sorted.				Sorted. 설정		設置Sorted。				
TOOLTIP_MINIMISE	Hide Side Panel	Hide Side Panel				측면 칸 숨기기		隱藏側窗格				
TOOLTIP_MAXIMISE	Show Side Panel	Show Side Panel				측면 칸 보이기		顯示側窗格				
TOOLTIP_KEYRING	Keyring	Keyring				열쇠고리		鑰匙圈				
TOOLTIP_CONTAINER_BACKPACK	Backpack	Backpack										
TOOLTIP_CONTAINER_BANK	Bank	Bank										
TOOLTIP_CONTAINER_REAGENTS	Reagents	Reagents										
TOOLTIP_CLEANUP_BAGS	< Click to Clean Up Bags >	< Click to Clean Up Bags >				< 가방 정리하기 >		< 點擊以整理背包 >				
TOOLTIP_CLEANUP_BANK	< Click to Clean Up Bank >	< Click to Clean Up Bank >				< 은행 정리하기 >		< 點擊以整理銀行 >				
TOOLTIP_CLEANUP_REAGENTS	< Click to Clean Up Reagents >	< Click to Clean Up Reagents >				< 재료 은행 정리하기 >		< 點擊以整理材料銀行 >				
TOOLTIP_FORGET_CHARACTER	Forget %s\n|cffffffffFree up memory by clearing the data that Sorted has kept on this characters.\n|cffff000000You will no longer be able to preview their items!	Forget %s\n|cffffffffFree up memory by clearing the data that Sorted has kept on this characters.\n|cffff000000You will no longer be able to preview their items!				%s 지우기\n|cffffffff이 캐릭터에 대한 Sorted의 데이터를 지워 메모리를 확보합니다. \n|cffff000000더 이상 이 캐릭터의 아이템을 확인할 수 없습니다!		遺忘 %s\n|cffffffff通過清除Sorted保留在此\n角色的數據來釋放記憶體。\n|cffff000000您將不再能夠預覽他們的物品！				
TOOLTIP_CONFIG_ALWAYS_USE_ICONS	Always Use Icons:\n|cffffffffHides the default category buttons and forces Sorted \nto use the icons instead, which usually only show when \nthe side pane is minimised.\n\n|cffffee00With this checked, and the side pane maximised, the entire height\nof the window will be used for the category's checkbuttons.\nIn this case, the side pane hides automatically.	Always Use Icons:\n|cffffffffHides the default category buttons and forces Sorted \nto use the icons instead, which usually only show when \nthe side pane is minimised.\n\n|cffffee00With this checked, and the side pane maximised, the entire height\nof the window will be used for the category's checkbuttons.\nIn this case, the side pane hides automatically.				항상 아이콘 사용하기:\n|cffffffffSorted가 원래의 카테고리 버튼 대신 아이콘을 사용하도록 합니다.\n일반적으론 측면 칸을 접은 경우에만 나타납니다.\n\n|cffffee00이 옵션을 체크하면 세부 분류를 고를 수 있는 공간이 최대화됩니다. 본래의 대분류 버튼은 자동으로 숨겨집니다.		永遠使用圖示:\n|cffffffff隱藏預設的類別文字按鈕，強制改用圖示\n就像是隱藏側窗格時所顯示的樣子\n\n|cffffee00勾選後,顯示側窗格時，整塊區域都會用來\n顯示類別的核取方塊，此時側窗格也會自動隱藏。				
TOOLTIP_CONFIG_SCROLL_WHEEL_SPEED	Wheel Scroll Speed:\n|cffffffffAdjust how far Sorted should scroll\nper each step of the scroll wheel.\n\n|cffffee00(You can hold ALT at any time to scroll quickly)	Wheel Scroll Speed:\n|cffffffffAdjust how far Sorted should scroll\nper each step of the scroll wheel.\n\n|cffffee00(You can hold ALT at any time to scroll quickly)				스크롤 속도:\n|cffffffff마우스 휠의 한 단계마다 Sorted가 스크롤할 범위를 조정합니다.\n\n|cffffee00(언제든지 ALT를 누르고 있으면 빠르게 스크롤할 수 있습니다)		滾輪捲動速度:\n|cffffffff調整Sorted的滾輪\n每一步應滾動的距離。\n\n|cffffee00(您可以隨時按住ALT快速滾動)				
TOOLTIP_CONFIG_SMOOTH_SCROLLING	Smooth Scrolling:\n|cffffffffToggles whether Sorted should smoothly animate\nwhen scrolling. Raise the smoothing strength to\nincrease the duration of the animation.\n\n|cffffee00(Disable to improve performance)	Smooth Scrolling:\n|cffffffffToggles whether Sorted should smoothly animate\nwhen scrolling. Raise the smoothing strength to\nincrease the duration of the animation.\n\n|cffffee00(Disable to improve performance)				부드러운 스크롤:\n|cffffffff스크롤 할 때 Sorted가 부드러운 애니메이션을 가하도록 조정합니다.\n부드러움 강도를 높여서 애니메이션 속도를 늘릴 수 있습니다.\n\n|cffffee00(비활성화하면 성능이 향상됨)		平滑捲動:\n|cffffffff切換Sorted是否有平滑的捲動動畫\n滾動時，提高平滑強度\n以增加動畫的持續時間。\n\n|cffffee00(停用來提高性能)				
TOOLTIP_CONFIG_RESET_ON_CLOSE	Reset Window on Close:\n|cffffffffLeave unchecked to have Sorted remember\nyour searching, filtering, and sorting options\nafter closing and reopening the window.	Reset Window on Close:\n|cffffffffLeave unchecked to have Sorted remember\nyour searching, filtering, and sorting options\nafter closing and reopening the window.				닫으면 창 초기화:\n|cffffffffSorted를 닫았다가 다시 열었을 때\n검색, 분류 및 정렬 우선도를 그대로 두려면\n체크하지 마십시오.		關閉後重設視窗:\n|cffffffff取消勾選以讓Sorted記憶\n您的搜尋，過濾和排序選項\n在關閉並重新開啟視窗之後。				
TOOLTIP_CONFIG_COMBINE_STACKS	Combine Stacks:\n|cffffffffMerges identical items into one line.\nInteracting with an item will interact with\nthe largest stack of that item in your bags.	Combine Stacks:\n|cffffffffMerges identical items into one line.\nInteracting with an item will interact with\nthe largest stack of that item in your bags.				갯수 합치기:\n|cffffffff같은 아이템을 한 줄로 합칩니다.\n아이템을 사용하면 해당 아이템 묶음 중\n가장 큰 묶음을 사용합니다.		合併堆疊:\n|cffffffff將相同的物品合併為一行。\n與物品進行互動將與您背包中\n該物品的最大堆疊物品互動。				
TOOLTIP_CONFIG_REMOVE_CATEGORY	Remove "%s"	Remove "%s"										
TOOLTIP_BUY_BANK_SLOT	Purchase Bag Slot	Purchase Bag Slot				가방 칸 구입		購買背包格位				
DIALOG_DELETE_CHARACTER_DATA	You will no longer be able to preview %s's items until you next play that character	You will no longer be able to preview %s's items until you next play that character										
DIALOG_DELETE_SETTINGS_PROFILE	Are you sure you want to delete the settings for profile '%s'?	Are you sure you want to delete the settings for profile '%s'?										
DIALOG_BUTTON_ACCEPT	Accept	Accept										
DIALOG_BUTTON_CANCEL	Cancel	Cancel										
DIALOG_BUTTON_DELETE	Delete	Delete										]]

    for row in string.gmatch(tsv, "[^\r\n]+") do
        local key = string.match(row, "(.-)\t")
        localizations["enUS"][key], localizations["enGB"][key], localizations["frFR"][key], localizations["deDE"][key],
        localizations["itIT"][key], localizations["koKR"][key], localizations["zhCN"][key], localizations["zhTW"][key],
        localizations["ruRU"][key], localizations["esES"][key], localizations["esMX"][key], localizations["ptBR"][key]
            = string.match(row, ".-\t(.-)\t(.-)\t(.-)\t(.-)\t(.-)\t(.-)\t(.-)\t(.-)\t(.-)\t(.-)\t(.-)\t(.*)")
    end
end
ParseTSV()

local clientLocale = GetLocale()
function Sorted.Localize(key)
    if localizations[clientLocale][key] and localizations[clientLocale][key] ~= "" then
        return localizations[clientLocale][key]
    elseif localizations["enUS"][key] then
        return localizations["enUS"][key]
    else
        return "["..key.."]"
    end
end